INSERT INTO roles VALUES
       (DEFAULT, 'Administrators', 'Senior level sys admins with vast write privilege'),
       (DEFAULT, 'Operators', 'On and off site sys admins'),
       (DEFAULT, 'Viewers', 'Read-only users');
--;;
INSERT INTO object_types VALUES
       ('node_groups', 'Node Groups', 'Node groups'),
       ('users', 'Users', 'Puppet Enterprise Console users'),
       ('user_groups', 'User Groups', 'Groups of users'),
       ('user_roles', 'User Roles', 'Define what users have permission to do'),
       ('activity_log', 'Activity Log', 'Logs user activity'),
       ('directory_service', 'Directory Service', 'Authenticates remote users'),
       ('console_page', 'Console Page', 'Pages in Puppet console');
--;;
INSERT INTO actions VALUES
       ('view', 'View', 'View a node group', 'node_groups', 'true'),
       ('modify_children', 'Create, Edit, & Delete Child Groups', 'Create, edit, and delete child groups below a given node group', 'node_groups', 'true'),
       ('edit_child_rules', 'Edit Child Group Rules', 'Edit rules of all groups below a given node group', 'node_groups', 'true'),
       ('set_environment', 'Set Environment', 'Edit a node group''s environment', 'node_groups', 'true'),
       ('edit_classification', 'Edit Classification and Variables', 'Edit a node group''s classification and variables', 'node_groups', 'true'),
       ('view', 'View', 'View a user', 'users', 'true'),
       ('create', 'Create', 'Create a local user', 'users', 'false'),
       ('reset_password', 'Reset Password', 'Reset a user''s password', 'users', 'true'),
       ('edit', 'Edit', 'Edit user information', 'users', 'true'),
       ('disable', 'Disable', 'Disable a user', 'users', 'true'),
       ('import', 'Import', 'Import a user group from AD/LDAP', 'user_groups', 'false'),
       ('view', 'View', 'View a user group', 'user_groups', 'true'),
       ('view', 'View', 'View a role', 'user_roles', 'true'),
       ('create', 'Create', 'Create a role', 'user_roles', 'false'),
       ('edit', 'Edit', 'Edit a role', 'user_roles', 'true'),
       ('edit_members', 'Edit Members', 'Edit a role''s members', 'user_roles', 'true'),
       ('edit', 'View, Edit, and Test', 'View, edit, and test the directory service settings', 'directory_service', 'false'),
       ('view', 'View', 'View the activity log', 'activity_log', 'false'),
       ('view', 'View', 'View a console page', 'console_page', 'false'),
       ('write', 'Write', 'Write to console pages', 'console_page', 'false');
--;;
INSERT INTO permissions VALUES
       (DEFAULT, 'node_groups', 'edit_child_rules', '*'),
       (DEFAULT, 'node_groups', 'modify_children', '*'),
       (DEFAULT, 'node_groups', 'set_environment', '*'),
       (DEFAULT, 'node_groups', 'edit_classification', '*'),
       (DEFAULT, 'node_groups', 'view', '*'),
       (DEFAULT, 'users', 'create', '*'),
       (DEFAULT, 'users', 'edit', '*'),
       (DEFAULT, 'users', 'reset_password', '*'),
       (DEFAULT, 'users', 'disable', '*'),
       (DEFAULT, 'users', 'view', '*'),
       (DEFAULT, 'user_groups', 'import', '*'),
       (DEFAULT, 'user_groups', 'view', '*'),
       (DEFAULT, 'user_roles', 'create', '*'),
       (DEFAULT, 'user_roles', 'edit', '*'),
       (DEFAULT, 'user_roles', 'edit_members', '*'),
       (DEFAULT, 'user_roles', 'view', '*'),
       (DEFAULT, 'activity_log', 'view', '*'),
       (DEFAULT, 'directory_service', 'edit', '*'),
       (DEFAULT, 'console_page', 'view', '*'),
       (DEFAULT, 'console_page', 'write', '*');
--;;
WITH jt
    (object_type, action, display_name)
AS
(VALUES
    ( 'node_groups', 'edit_child_rules', 'Administrators' ),
    ( 'node_groups', 'modify_children', 'Administrators' ),
    ( 'node_groups', 'set_environment', 'Administrators' ),
    ( 'node_groups', 'edit_classification', 'Administrators' ),
    ( 'node_groups', 'view', 'Administrators' ),

    ( 'users', 'create', 'Administrators' ),
    ( 'users', 'edit', 'Administrators' ),
    ( 'users', 'reset_password', 'Administrators' ),
    ( 'users', 'disable', 'Administrators' ),
    ( 'users', 'view', 'Administrators' ),

    ( 'user_groups', 'import', 'Administrators' ),
    ( 'user_groups', 'view', 'Administrators' ),

    ( 'user_roles', 'create', 'Administrators' ),
    ( 'user_roles', 'edit', 'Administrators' ),
    ( 'user_roles', 'edit_members', 'Administrators' ),
    ( 'user_roles', 'view', 'Administrators' ),

    ( 'activity_log', 'view', 'Administrators' ),

    ( 'directory_service', 'edit', 'Administrators'),

    ( 'console_page', 'write', 'Administrators' ),
    ( 'console_page', 'view', 'Administrators' ),
-----------------------------------------------------------
    ( 'node_groups', 'edit_child_rules', 'Operators' ),
    ( 'node_groups', 'modify_children', 'Operators' ),
    ( 'node_groups', 'set_environment', 'Operators' ),
    ( 'node_groups', 'edit_classification', 'Operators' ),
    ( 'node_groups', 'view', 'Operators' ),

    ( 'users', 'edit', 'Operators' ),
    ( 'users', 'view', 'Operators' ),

    ( 'user_groups', 'import', 'Operators' ),
    ( 'user_groups', 'view', 'Operators' ),

    ( 'user_roles', 'edit', 'Operators' ),
    ( 'user_roles', 'edit_members', 'Operators' ),
    ( 'user_roles', 'view', 'Operators' ),

    ( 'activity_log', 'view', 'Operators' ),

    ( 'console_page', 'write', 'Operators' ),
    ( 'console_page', 'view', 'Operators' ),
----------------------------------------------------------
    ( 'users', 'view', 'Viewers' ),

    ( 'user_groups', 'view', 'Viewers' ),

    ( 'node_groups', 'view', 'Viewers' ),

    ( 'activity_log', 'view', 'Viewers' ),

    ( 'console_page', 'view', 'Viewers' ),

    ( 'user_roles', 'view', 'Viewers' )
)
INSERT INTO roles_permissions (SELECT p.id AS pid, r.id AS rid FROM
    permissions p
JOIN jt ON jt.object_type = p.object_type AND jt.action = p.action AND p.instance = '*'
JOIN roles r ON r.display_name = jt.display_name);
